﻿using MigraDoc.DocumentObjectModel;
using PdfSharp.Pdf;
using PdfSharp.Drawing;
using MigraDoc.Rendering;

namespace ConsoleApplication1
{
    class Program
    {
        static void Main()
        {
            using (var pdf = new PdfDocument())
            {
                var page = pdf.AddPage();
                var doc = new Document();

                doc.Styles[StyleNames.Normal].Font.Size = 8;
                var style = doc.Styles.AddStyle("Table", "Normal");
                style = doc.Styles.AddStyle("CellTitle", "Table");
                style.ParagraphFormat.TabStops.AddTabStop("4cm", TabAlignment.Right, TabLeader.Dots);

                var sec = doc.AddSection();
                var table = sec.AddTable();
                table.Style = "Table";
                table.Format.Font.Size = 8;
                table.Borders.Distance = 0;
                table.Borders.Color = Colors.DarkGray;

                table.AddColumn("4cm");
                table.AddColumn("4cm");

                var row = table.Rows.AddRow();
                row.Cells[0].Style = "CellTitle";
                row.Cells[0].Shading.Color = Colors.LightBlue;

                var para = row.Cells[0].AddParagraph("MEMBER NO\tID");
                para.Format.Borders.Color = Colors.Red;

                row = table.AddRow();
                para = row.Cells[0].AddParagraph("000000323\t026");
                para.Format.AddTabStop("4cm", TabAlignment.Right);
                para.Format.Borders.Color = Colors.Red;

                var renderer = new DocumentRenderer(doc);
                renderer.PrepareDocument();
                using (var gfx = XGraphics.FromPdfPage(page))
                {
                    renderer.RenderObject(gfx, XUnit.FromMillimeter(20), XUnit.FromMillimeter(20), XUnit.FromMillimeter(double.MaxValue), table);
                }

                var filePath = System.IO.Path.GetTempFileName() + ".pdf";
                pdf.Save(filePath);
                System.Diagnostics.Process.Start(filePath);
            }
        }
    }
}
